import { Component, Input, EventEmitter, ChangeDetectionStrategy, HostListener, Output } from '@angular/core';
import { stopPropagationIfExist } from '../utils/dom-utils';
var ActionButtonComponent = (function () {
    function ActionButtonComponent() {
        this.type = 'default';
        this.direction = 'down';
        this.isOpen = false;
        this.disabled = false;
        this.actionClick = new EventEmitter();
        this.openStatusChange = new EventEmitter();
    }
    ActionButtonComponent.prototype.toggle = function ($event) {
        stopPropagationIfExist($event);
        this.isOpen = !this.isOpen;
        this.openStatusChange.emit(this.isOpen);
    };
    ActionButtonComponent.prototype.close = function ($event) {
        this.isOpen = false;
        this.openStatusChange.emit(this.isOpen);
    };
    ActionButtonComponent.prototype.onActionClick = function (item) {
        if (!item.disabled) {
            this.close();
            this.actionClick.emit(item);
        }
    };
    return ActionButtonComponent;
}());
export { ActionButtonComponent };
ActionButtonComponent.decorators = [
    { type: Component, args: [{
                selector: 're-action-button',
                template: "\n    <ng-template #defaultButtonTemplate let-action>\n      <button class=\"btn {{action.type? 'btn-' + action.type : ''}} {{action.btnSize? 'btn-' + action.btnSize : ''}}\"\n              (click)=\"action.toggle($event)\"\n              [disabled]=\"action.disabled\">\n        <i *ngIf=\"action.icon\" class=\"{{action.icon}}\" aria-hidden=\"true\"></i>\n        {{action.buttonText}}\n      </button>\n      <button type=\"button\"\n              class=\"btn {{action.type? 'btn-' + action.type : ''}} {{action.btnSize? 'btn-' + action.btnSize : ''}} dropdown-toggle\"\n              aria-haspopup=\"true\"\n              [attr.aria-expanded]=\"true\"\n              (click)=\"action.toggle($event)\" [disabled]=\"action.disabled\">\n        <span class=\"caret\"></span>\n        <span class=\"sr-only\">|</span>\n      </button>\n    </ng-template>\n\n    <div class=\"btn-group {{direction? 'drop' + direction : '' }} {{cssClass}}\" [ngClass]=\"{open: isOpen}\">\n\n      <ng-template [ngTemplateOutlet]=\"buttonTemplate || defaultButtonTemplate\"\n                   [ngOutletContext]=\"{ $implicit: this}\"></ng-template>\n\n      <ul class=\"dropdown-menu\" role=\"menu\">\n        <ng-container *ngFor=\"let item of actions\">\n          <li *ngIf=\"!item.divider && ! item.header\" role=\"menuitem\" [ngClass]=\"{'disabled': item.disabled}\"\n              (click)=\"onActionClick(item)\">\n            <a><i *ngIf=\"item.icon\" class=\"{{item.icon}}\"></i>&nbsp;{{item.text}}</a></li>\n          <li *ngIf=\"item.header\" class=\"dropdown-header\">{{item.text}}</li>\n          <li *ngIf=\"item.divider\" class=\"divider\" role=\"separator\"></li>\n        </ng-container>\n      </ul>\n    </div>\n  ",
                changeDetection: ChangeDetectionStrategy.OnPush,
            },] },
];
/** @nocollapse */
ActionButtonComponent.ctorParameters = function () { return []; };
ActionButtonComponent.propDecorators = {
    'type': [{ type: Input },],
    'direction': [{ type: Input },],
    'icon': [{ type: Input },],
    'btnSize': [{ type: Input },],
    'buttonText': [{ type: Input },],
    'cssClass': [{ type: Input },],
    'isOpen': [{ type: Input },],
    'actions': [{ type: Input },],
    'disabled': [{ type: Input },],
    'buttonTemplate': [{ type: Input },],
    'actionClick': [{ type: Output },],
    'openStatusChange': [{ type: Output },],
    'close': [{ type: HostListener, args: ['document:click', ['$event'],] },],
};
//# sourceMappingURL=action-button.component.js.map