import { Component, ChangeDetectionStrategy, Input } from '@angular/core';
import { DataTableComponent } from './data-table.component';
var DataTableHeadComponent = (function () {
    function DataTableHeadComponent(dt) {
        this.dt = dt;
        this.searchQuery = {};
    }
    DataTableHeadComponent.prototype.onHeadClick = function (column) {
        if (!column.sortable) {
            return;
        }
        if (this.sortField === column.field) {
            this.sortDirection = this.sortDirection === 'ASC' ? 'DESC' : 'ASC';
        }
        else {
            this.sortField = column.field;
            this.sortDirection = 'ASC';
        }
        this.dt.sortChange.emit({ field: this.sortField, direction: this.sortDirection, column: column });
    };
    DataTableHeadComponent.prototype.hasAnyFilterColumns = function (columns) {
        return (columns || []).some(function (col) { return col.filterable; });
    };
    DataTableHeadComponent.prototype.onCheckAllChange = function () {
        this.dt.onCheckAllChange(this.allChecked);
    };
    DataTableHeadComponent.prototype.onSearchQueryChange = function () {
        this.dt.onSearchQueryChange(this.searchQuery);
    };
    DataTableHeadComponent.prototype.canFilterable = function (column) {
        return column.field && column.field !== '$index' && column.filterable;
    };
    return DataTableHeadComponent;
}());
export { DataTableHeadComponent };
DataTableHeadComponent.decorators = [
    { type: Component, args: [{
                selector: 're-data-table-head,[reDataTableHead]',
                template: "\n    <ng-container>\n      <ng-template [ngTemplateOutlet]=\"headTemplate ? headTemplate.template : dataTableTemplates.headTemplate\"\n                [ngOutletContext]=\"{ $implicit: this }\">\n      </ng-template>\n\n      <!--filter row-->\n      <tr *ngIf=\"hasAnyFilterColumns(columns)\">\n        <th *ngIf=\"checkable\"></th>\n        <th *ngFor=\"let column of columns\">\n          <ng-container *ngIf=\"canFilterable(column)\">\n            <ng-template [ngTemplateOutlet]=\"dataTableTemplates.getCellFilterTemplate(column)\"\n                      [ngOutletContext]=\"{ $implicit: this , column: column}\">\n            </ng-template>\n          </ng-container>\n        </th>\n      </tr>\n    </ng-container>\n  ",
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
DataTableHeadComponent.ctorParameters = function () { return [
    { type: DataTableComponent, },
]; };
DataTableHeadComponent.propDecorators = {
    'checkable': [{ type: Input },],
    'allChecked': [{ type: Input },],
    'headTemplate': [{ type: Input },],
    'columns': [{ type: Input },],
    'dataTableTemplates': [{ type: Input },],
};
//# sourceMappingURL=data-table-head.component.js.map