import { Component, ChangeDetectionStrategy, Input, ContentChildren, Output, EventEmitter, ContentChild, ViewChild, HostListener } from '@angular/core';
import { DataTableColumnTmplComponent } from './tmpl/data-table-column-tmpl.component';
import { DataTableHeadTmplComponent } from './tmpl/data-table-head-tmpl.component';
import { DataTableFootTmplComponent } from './tmpl/data-table-foot-tmpl.component';
import { DataTableTmplsComponent } from './tmpl/data-table-tmpls.component';
import { DataTablePagerTmplComponent } from './tmpl/data-table-pager-tmpl.component';
var DataTableComponent = (function () {
    function DataTableComponent() {
        this.dataSource = [];
        this.editModel = 'cell';
        this.type = '';
        this.hover = true;
        this.tableWidth = '100%';
        this.cellClick = new EventEmitter();
        this.cellDBClick = new EventEmitter();
        this.rowClick = new EventEmitter();
        this.rowDBClick = new EventEmitter();
        this.cellEditStart = new EventEmitter();
        this.cellEditEnd = new EventEmitter();
        this.sortChange = new EventEmitter();
        this.rowCheckChange = new EventEmitter();
        this.checkAllChange = new EventEmitter();
        this.searchQueryChange = new EventEmitter();
        this.pageIndexChange = new EventEmitter();
        this.documentClickEvent = new EventEmitter();
    }
    DataTableComponent.prototype.onDocumentClick = function ($event) {
        this.documentClickEvent.emit($event);
    };
    DataTableComponent.prototype.onCellClick = function ($event) {
        this.selectedRowItem = $event.rowItem;
        this.selectedColumnItem = $event.column;
        this.cellClick.emit($event);
    };
    DataTableComponent.prototype.onCellEditStart = function ($event) {
        this.isCellEdit = true;
        this.cellEditStart.emit($event);
    };
    DataTableComponent.prototype.onCellEditEnd = function ($event) {
        this.isCellEdit = false;
        this.cellEditEnd.emit($event);
    };
    DataTableComponent.prototype.onCellDBClick = function ($event) {
        this.cellDBClick.emit($event);
    };
    DataTableComponent.prototype.onRowClick = function ($event) {
        this.selectedRowItem = $event.rowItem;
        this.rowClick.emit($event);
    };
    DataTableComponent.prototype.onRowDBClick = function ($event) {
        this.rowDBClick.emit($event);
    };
    DataTableComponent.prototype.onRowCheckChange = function ($event) {
        this.allChecked = !this.dataSource.some(function (item) { return !item.$$checked; });
        this.rowCheckChange.emit($event);
    };
    DataTableComponent.prototype.onCheckAllChange = function ($event) {
        if (this.dataSource) {
            this.dataSource = this.dataSource.map(function (item) {
                item.$$checked = $event;
                return item;
            });
        }
        this.allChecked = $event;
        this.checkAllChange.emit($event);
    };
    DataTableComponent.prototype.onSearchQueryChange = function ($event) {
        this.searchQueryChange.emit($event);
    };
    DataTableComponent.prototype.onPageChange = function ($event) {
        this.pageIndexChange.emit($event);
    };
    DataTableComponent.prototype.getCheckRows = function () {
        return this.dataSource ? this.dataSource.filter(function (item) { return item.$$checked; }) : [];
    };
    DataTableComponent.prototype.getSelectedRowItem = function () {
        return this.selectedRowItem;
    };
    DataTableComponent.prototype.editRow = function (rowItem, editModel) {
        rowItem.$$edit = true;
        rowItem.$$editModel = editModel;
        this.editRowItem = rowItem;
    };
    DataTableComponent.prototype.endEditRow = function (rowItem) {
        var editModel = rowItem.$$editModel;
        delete rowItem.$$edit;
        delete rowItem.$$editModel;
        this.editRowItem = null;
        return editModel;
    };
    DataTableComponent.prototype.ngOnDestroy = function () {
    };
    return DataTableComponent;
}());
export { DataTableComponent };
DataTableComponent.decorators = [
    { type: Component, args: [{
                selector: 're-data-table',
                template: "\n    <re-data-table-templates></re-data-table-templates>\n\n    <div class=\"panel panel-default data-table {{cssClass}}\">\n      <!--<div class=\"panel-heading text-center\">Panel heading</div>-->\n      <div class=\"table-view\" *ngIf=\"scrollable\" [style.width]=\"tableWidth\">\n        <table class=\"table {{type ? 'table-' + type : ''}} {{ hover ? 'table-hover': ''}}\">\n          <thead reDataTableHead [columns]=\"columns\" [headTemplate]=\"headTemplate\" [checkable]=\"checkable\"\n                 [allChecked]=\"allChecked\" [dataTableTemplates]=\"dataTableTemplates\"></thead>\n        </table>\n      </div>\n\n      <div class=\"table-view\" [ngClass]=\"{'scroll-view': scrollable}\" [style.max-height]=\"maxHeight\" [style.width]=\"tableWidth\">\n        <table class=\"table {{type ? 'table-' + type : ''}} {{ hover ? 'table-hover': ''}}\">\n          <thead *ngIf=\"!scrollable\" reDataTableHead [dataTableTemplates]=\"dataTableTemplates\" [columns]=\"columns\"\n                 [headTemplate]=\"headTemplate\" [checkable]=\"checkable\" [allChecked]=\"allChecked\"></thead>\n\n          <tbody reDataTableBody [dataTableTemplates]=\"dataTableTemplates\" [dataSource]=\"dataSource\" [columns]=\"columns\"\n                 [checkable]=\"checkable\" [allChecked]=\"allChecked\" [selectable]=\"selectable\"\n                 [editModel]=\"editModel\" [editRowItem]=\"editRowItem\"></tbody>\n          <tfoot *ngIf=\"footTemplate\" reDataTableFoot [footTemplate]=\"footTemplate\"></tfoot>\n        </table>\n      </div>\n      <div class=\"panel-footer table-view-footer text-center\" *ngIf=\"pager\">\n        <re-data-table-pager [pager]=\"pager\" [dataTableTemplates]=\"dataTableTemplates\"\n                             [pagerTemplate]=\"pagerTemplate\"></re-data-table-pager>\n      </div>\n    </div>\n  ",
                styles: ["\n    .data-table{border:none;overflow-x:auto}.data-table .table-view{padding:0px;border:none}.data-table .table-view .table{margin:0px}.data-table .table-view.scroll-view{overflow-y:auto;overflow-x:hidden}.data-table .table-view-footer{border:none;margin:0px}:host /deep/ .table-pagination .pagination{margin:0px}:host /deep/ .checkable-cell{width:25px}\n  "],
                changeDetection: ChangeDetectionStrategy.OnPush,
                exportAs: 'dataTable'
            },] },
];
/** @nocollapse */
DataTableComponent.ctorParameters = function () { return []; };
DataTableComponent.propDecorators = {
    'dataSource': [{ type: Input },],
    'checkable': [{ type: Input },],
    'selectable': [{ type: Input },],
    'scrollable': [{ type: Input },],
    'editModel': [{ type: Input },],
    'maxHeight': [{ type: Input },],
    'type': [{ type: Input },],
    'hover': [{ type: Input },],
    'allChecked': [{ type: Input },],
    'pager': [{ type: Input },],
    'cssClass': [{ type: Input },],
    'tableWidth': [{ type: Input },],
    'cellClick': [{ type: Output },],
    'cellDBClick': [{ type: Output },],
    'rowClick': [{ type: Output },],
    'rowDBClick': [{ type: Output },],
    'cellEditStart': [{ type: Output },],
    'cellEditEnd': [{ type: Output },],
    'sortChange': [{ type: Output },],
    'rowCheckChange': [{ type: Output },],
    'checkAllChange': [{ type: Output },],
    'searchQueryChange': [{ type: Output },],
    'pageIndexChange': [{ type: Output },],
    'columns': [{ type: ContentChildren, args: [DataTableColumnTmplComponent,] },],
    'headTemplate': [{ type: ContentChild, args: [DataTableHeadTmplComponent,] },],
    'footTemplate': [{ type: ContentChild, args: [DataTableFootTmplComponent,] },],
    'pagerTemplate': [{ type: ContentChild, args: [DataTablePagerTmplComponent,] },],
    'dataTableTemplates': [{ type: ViewChild, args: [DataTableTmplsComponent,] },],
    'onDocumentClick': [{ type: HostListener, args: ['document:click', ['$event'],] },],
};
//# sourceMappingURL=data-table.component.js.map