import { Component, Input, Output, EventEmitter, ChangeDetectionStrategy } from '@angular/core';
import { RebirthNGConfig } from '../rebirth-ng.config';
var PaginationComponent = (function () {
    function PaginationComponent(rebirthUIConfig) {
        this.rebirthUIConfig = rebirthUIConfig;
        this.total = 0;
        this.pageIndex = 1;
        this.pageIndexChange = new EventEmitter();
        this.showPages = [];
        this.totalPage = 0;
        this.boundary = rebirthUIConfig.pagination.boundary;
        this.pageSize = rebirthUIConfig.pagination.pageSize;
        this.maxItems = rebirthUIConfig.pagination.maxItems;
        this.firstLink = rebirthUIConfig.pagination.button.first;
        this.lastLink = rebirthUIConfig.pagination.button.last;
        this.preLink = rebirthUIConfig.pagination.button.pre;
        this.nextLink = rebirthUIConfig.pagination.button.next;
        this.size = rebirthUIConfig.pagination.size;
    }
    PaginationComponent.prototype.first = function () {
        if (this.pageIndex !== 1) {
            this.onPageIndexChange(1);
        }
    };
    PaginationComponent.prototype.last = function () {
        var last = Math.max(this.totalPage, 1);
        if (this.pageIndex !== last) {
            this.onPageIndexChange(last);
        }
    };
    PaginationComponent.prototype.prev = function () {
        if (this.hasPrev()) {
            this.onPageIndexChange(this.pageIndex - 1);
        }
    };
    PaginationComponent.prototype.next = function () {
        if (this.hasNext()) {
            this.onPageIndexChange(this.pageIndex + 1);
        }
    };
    PaginationComponent.prototype.preRange = function () {
        var pre = this.showPages[0] - 1;
        this.onPageIndexChange(Math.max(pre, 1));
    };
    PaginationComponent.prototype.nextRange = function () {
        var next = this.showPages[this.showPages.length - 1] + 1;
        this.onPageIndexChange(Math.min(next, this.totalPage));
    };
    PaginationComponent.prototype.onPageIndexChange = function (pageIndex) {
        if (this.pageIndex !== pageIndex) {
            this.pageIndexChange.emit(pageIndex);
        }
    };
    PaginationComponent.prototype.hasPrev = function () {
        return this.pageIndex > 1;
    };
    PaginationComponent.prototype.hasNext = function () {
        return this.pageIndex < this.totalPage;
    };
    PaginationComponent.prototype.getTotalPage = function () {
        return Math.ceil(this.total / this.pageSize);
    };
    PaginationComponent.prototype.ngOnChanges = function (changes) {
        var shouldUpdateRanges = PaginationComponent.EFFECT_PAGE_RANGE_KEYS.some(function (key) { return !!changes[key]; });
        if (shouldUpdateRanges) {
            this.totalPage = this.getTotalPage();
            this.pageIndex = Math.max(Math.min(this.pageIndex, this.totalPage), 1);
            this.updateShowPageRange();
        }
    };
    PaginationComponent.prototype.updateShowPageRange = function () {
        if (!this.totalPage) {
            this.showPages = [];
            return;
        }
        if (this.totalPage <= this.maxItems) {
            this.showPages = new Array(this.totalPage).fill(0).map(function (_, i) { return i + 1; });
            return;
        }
        this.showPages = this.extractRange();
    };
    PaginationComponent.prototype.extractRange = function () {
        var _this = this;
        var showPages = [this.pageIndex];
        var start = this.pageIndex - 1;
        var end = this.pageIndex + 1;
        var arriveLeftBound = function (index) { return index < 1; };
        var arriveRightBound = function (index) { return index > _this.totalPage; };
        var fullPageRang = function (pages) { return pages.length >= _this.maxItems; };
        while (!(fullPageRang(showPages) || (arriveLeftBound(start) && arriveRightBound(end)))) {
            if (!arriveLeftBound(start)) {
                showPages.unshift((start--));
            }
            if (!fullPageRang(showPages) && !arriveRightBound(end)) {
                showPages.push(end++);
            }
        }
        return showPages;
    };
    return PaginationComponent;
}());
export { PaginationComponent };
PaginationComponent.EFFECT_PAGE_RANGE_KEYS = ['total', 'pageSize', 'pageIndex', 'maxItems'];
PaginationComponent.decorators = [
    { type: Component, args: [{
                selector: 're-pagination',
                template: "\n    <nav aria-label=\"Pagination\" class=\"{{cssClass}}\">\n      <ul class=\"pagination {{size? 'pagination-' + size: ''}}\">\n        <li *ngIf=\"boundary\" [ngClass]=\"{disabled: pageIndex == 1}\">\n          <a [attr.aria-label]=\"firstLink\" (click)=\"first()\"><span aria-hidden=\"true\">{{firstLink}}</span></a>\n        </li>\n        <li [ngClass]=\"{disabled: pageIndex == 1}\">\n          <a (click)=\"prev()\" [attr.aria-label]=\"preLink\"><span aria-hidden=\"true\">{{preLink}}</span></a>\n        </li>\n        <li *ngIf=\"showPages[0] > 1\" (click)=\"preRange()\">\n          <a>...</a>\n        </li>\n        <li *ngFor=\"let item of showPages\" [ngClass]=\"{active: item == pageIndex}\">\n          <a (click)=\"onPageIndexChange(item)\">{{item}} <span class=\"sr-only\" *ngIf=\"item == pageIndex\">(current)</span></a>\n        </li>\n        <li *ngIf=\"showPages[showPages.length -1] < totalPage\" (click)=\"nextRange()\">\n          <a>...</a>\n        </li>\n        <li [ngClass]=\"{disabled: pageIndex == totalPage}\">\n          <a (click)=\"next()\" [attr.aria-label]=\"nextLink\"><span aria-hidden=\"true\">{{nextLink}}</span></a>\n        </li>\n        <li *ngIf=\"boundary\" [ngClass]=\"{disabled: pageIndex == totalPage}\">\n          <a [attr.aria-label]=\"lastLink\" (click)=\"last()\"><span aria-hidden=\"true\">{{lastLink}}</span></a>\n        </li>\n      </ul>\n    </nav>\n  ",
                exportAs: 'pagination',
                changeDetection: ChangeDetectionStrategy.OnPush
            },] },
];
/** @nocollapse */
PaginationComponent.ctorParameters = function () { return [
    { type: RebirthNGConfig, },
]; };
PaginationComponent.propDecorators = {
    'boundary': [{ type: Input },],
    'total': [{ type: Input },],
    'pageSize': [{ type: Input },],
    'pageIndex': [{ type: Input },],
    'pageIndexChange': [{ type: Output },],
    'maxItems': [{ type: Input },],
    'firstLink': [{ type: Input },],
    'lastLink': [{ type: Input },],
    'preLink': [{ type: Input },],
    'nextLink': [{ type: Input },],
    'size': [{ type: Input },],
    'cssClass': [{ type: Input },],
};
//# sourceMappingURL=pagination.component.js.map