import { Input, TemplateRef, HostListener } from '@angular/core';
import { stopPropagationIfExist } from '../utils/dom-utils';
var TooltipPopup = (function () {
    function TooltipPopup(elementRef, renderer) {
        this.elementRef = elementRef;
        this.renderer = renderer;
        this.placement = 'top';
    }
    TooltipPopup.prototype.onDocumentClick = function ($event) {
        stopPropagationIfExist($event);
    };
    TooltipPopup.prototype.show = function () {
        this.isOpen = true;
        this.renderer.addClass(this.elementRef.nativeElement, TooltipPopup.ACTIVE_CLASS);
        this.renderer.setStyle(this.elementRef.nativeElement, 'display', 'block');
        if (this.cssClass) {
            this.renderer.addClass(this.elementRef.nativeElement, this.cssClass);
        }
    };
    TooltipPopup.prototype.hide = function () {
        this.isOpen = false;
        this.renderer.removeClass(this.elementRef.nativeElement, TooltipPopup.ACTIVE_CLASS);
        this.renderer.setStyle(this.elementRef.nativeElement, 'display', 'none');
        if (this.cssClass) {
            this.renderer.removeClass(this.elementRef.nativeElement, this.cssClass);
        }
    };
    TooltipPopup.prototype.isTemplateRef = function (obj) {
        return obj != null && obj instanceof TemplateRef && obj.elementRef;
    };
    return TooltipPopup;
}());
export { TooltipPopup };
TooltipPopup.ACTIVE_CLASS = 'in';
TooltipPopup.propDecorators = {
    'placement': [{ type: Input },],
    'content': [{ type: Input },],
    'context': [{ type: Input },],
    'cssClass': [{ type: Input },],
    'onDocumentClick': [{ type: HostListener, args: ['click', ['$event'],] },],
};
//# sourceMappingURL=tooltip-popup.js.map