import { Input, HostListener } from '@angular/core';
var Tooltip = (function () {
    function Tooltip(viewContainerRef, elementRef, componentFactoryResolver, injector, positionService, renderer) {
        this.viewContainerRef = viewContainerRef;
        this.elementRef = elementRef;
        this.componentFactoryResolver = componentFactoryResolver;
        this.injector = injector;
        this.positionService = positionService;
        this.renderer = renderer;
        this.trigger = 'hover';
        this.placement = 'top';
        this.triggers = {
            hover: ['mouseenter', 'mouseleave'],
            focus: ['focusin', 'focusout'],
            click: ['click'],
            manual: []
        };
        this.listens = [];
    }
    Tooltip.prototype.ngOnInit = function () {
        var factory = this.componentFactoryResolver.resolveComponentFactory(this.tooltipPopupType);
        this.popupRef = this.viewContainerRef.createComponent(factory, 0, this.injector);
        this.fillPopup();
        this.registerTriggers();
    };
    Tooltip.prototype.onDocumentClick = function ($event) {
        if (this.trigger !== 'manual') {
            var hostElement = this.elementRef.nativeElement;
            if ($event.target !== hostElement) {
                this.hide();
            }
        }
    };
    Tooltip.prototype.ngOnDestroy = function () {
        this.listens.forEach(function (unregister) { return unregister(); });
        this.removePopView();
    };
    Tooltip.prototype.removePopView = function () {
        if (this.popupRef) {
            this.popupRef.destroy();
        }
    };
    Tooltip.prototype.toggle = function () {
        if (this.popupRef.instance.isOpen) {
            return this.hide();
        }
        this.show();
    };
    Tooltip.prototype.show = function () {
        this.fillPopup();
        this.popupRef.instance.show();
        this.positionTooltip();
    };
    Tooltip.prototype.hide = function () {
        if (this.popupRef) {
            var popupComponent = this.popupRef.instance;
            popupComponent.hide();
        }
    };
    Tooltip.prototype.registerTriggers = function () {
        var _this = this;
        var hostElement = this.elementRef.nativeElement;
        var trigger = this.triggers[this.trigger];
        if (trigger[0]) {
            this.listens.push(this.renderer.listen(hostElement, trigger[0], function () { return _this.show(); }));
        }
        if (trigger[1]) {
            this.listens.push(this.renderer.listen(hostElement, trigger[1], function () { return _this.hide(); }));
        }
    };
    Tooltip.prototype.positionTooltip = function () {
        var hostElement = this.elementRef.nativeElement;
        var targetElement = this.popupRef.location.nativeElement;
        var clientRect = this.positionService.positionElements(hostElement, targetElement, this.placement, false);
        this.renderer.setStyle(targetElement, 'left', clientRect.left + "px");
        this.renderer.setStyle(targetElement, 'top', clientRect.top + "px");
    };
    Tooltip.prototype.fillPopup = function () {
        var popupComponent = this.popupRef.instance;
        popupComponent.content = this.getContent();
        popupComponent.cssClass = this.cssClass;
        popupComponent.context = this.context || {};
        popupComponent.placement = this.placement;
        return popupComponent;
    };
    return Tooltip;
}());
export { Tooltip };
Tooltip.propDecorators = {
    'context': [{ type: Input },],
    'cssClass': [{ type: Input },],
    'trigger': [{ type: Input },],
    'placement': [{ type: Input },],
    'onDocumentClick': [{ type: HostListener, args: ['document:click', ['$event'],] },],
};
//# sourceMappingURL=tooltip.js.map